From 619c0a544d16d91ce933cf96f4d3a0101410c320 Mon Sep 17 00:00:00 2001
From: Sergey Radionov <RSATom@gmail.com>
Date: Mon, 21 Nov 2011 09:57:07 +0700
Subject: [PATCH] npapi: Changed files to be compilable by VC.

---
 npapi/control/npolibvlc.cpp |    8 +++++++-
 npapi/control/nporuntime.h  |    7 +++++++
 npapi/control/position.h    |    4 ++++
 npapi/support/npwin.cpp     |   11 +++++++++--
 npapi/vlcplugin.cpp         |    8 ++++++++
 npapi/vlcplugin.h           |   11 +++++++++++
 6 files changed, 46 insertions(+), 3 deletions(-)

diff --git a/npapi/control/npolibvlc.cpp b/npapi/control/npolibvlc.cpp
index 515c459..96ab261 100644
--- a/npapi/control/npolibvlc.cpp
+++ b/npapi/control/npolibvlc.cpp
@@ -1871,12 +1871,18 @@ LibvlcLogoNPObject::invoke(int index, const NPVariant *args,
     return INVOKERESULT_NO_ERROR;
 }
 
-
+#ifdef _MSC_VER
+const NPUTF8 * const LibvlcDeinterlaceNPObject::propertyNames[] = {
+    ""
+};
+const int LibvlcDeinterlaceNPObject::propertyCount=0;
+#else
 const NPUTF8 * const LibvlcDeinterlaceNPObject::propertyNames[] = {
 };
 enum LibvlcDeinterlaceNPObjectPropertyIds {
 };
 COUNTNAMES(LibvlcDeinterlaceNPObject,propertyCount,propertyNames);
+#endif //_MSC_VER
 
 RuntimeNPObject::InvokeResult
 LibvlcDeinterlaceNPObject::getProperty(int index, NPVariant &result)
diff --git a/npapi/control/nporuntime.h b/npapi/control/nporuntime.h
index fe9bfc6..c58864f 100644
--- a/npapi/control/nporuntime.h
+++ b/npapi/control/nporuntime.h
@@ -29,7 +29,14 @@
 ** support framework for runtime script objects
 */
 
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
 #include <npapi.h>
+#endif //_MSC_VER
+
 #include <npruntime.h>
 
 static void RuntimeNPClassDeallocate(NPObject *npobj);
diff --git a/npapi/control/position.h b/npapi/control/position.h
index ec1c7f8..1081830 100644
--- a/npapi/control/position.h
+++ b/npapi/control/position.h
@@ -22,6 +22,10 @@
 #ifndef POSITION_H
 #define POSITION_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 struct posidx_s { const char *n; size_t i; };
 static const posidx_s posidx[] = {
     { "center",        0 },
diff --git a/npapi/support/npwin.cpp b/npapi/support/npwin.cpp
index 7fe6d31..f9ef0fd 100644
--- a/npapi/support/npwin.cpp
+++ b/npapi/support/npwin.cpp
@@ -35,8 +35,15 @@
 #include "../vlcplugin.h"
 
 #ifndef _NPAPI_H_
-#   include "npapi.h"
-#endif
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
+#include <npapi.h>
+#endif //_MSC_VER
+#endif //_NPAPI_H_
+
 #if (((NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR) < 20)
 #include "npupp.h"
 #else
diff --git a/npapi/vlcplugin.cpp b/npapi/vlcplugin.cpp
index 41c5e83..b27f97c 100644
--- a/npapi/vlcplugin.cpp
+++ b/npapi/vlcplugin.cpp
@@ -26,6 +26,10 @@
 /*****************************************************************************
  * Preamble
  *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "vlcplugin.h"
 
 #include "control/npolibvlc.h"
@@ -443,7 +447,11 @@ void VlcPlugin::event_callback(const libvlc_event_t* event,
     plugin->events.callback(event, npparams, npcount);
     NPN_PluginThreadAsyncCall(plugin->getBrowser(), eventAsync, plugin);
 #else
+#ifdef _MSC_VER
+#pragma message("NPN_PluginThreadAsyncCall not implemented yet.")
+#else
 #warning NPN_PluginThreadAsyncCall not implemented yet.
+#endif //_MSC_VER
     printf("No NPN_PluginThreadAsyncCall(), doing nothing.\n");
 #endif
 }
diff --git a/npapi/vlcplugin.h b/npapi/vlcplugin.h
index 8b4a566..bf410fb 100644
--- a/npapi/vlcplugin.h
+++ b/npapi/vlcplugin.h
@@ -29,6 +29,10 @@
 #ifndef __VLCPLUGIN_H__
 #define __VLCPLUGIN_H__
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <vlc/vlc.h>
 
 // Setup XP_MACOSX, XP_UNIX, XP_WIN
@@ -80,7 +84,14 @@
 
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 
+#ifdef _MSC_VER
+//to avoid including <npapi.h> from Microsoft SDK (rather then from Mozilla SDK),
+//#include it indirectly via <npfunctions.h>
+#include <npfunctions.h>
+#else
 #include <npapi.h>
+#endif //_MSC_VER
+
 #include <vector>
 #include <assert.h>
 
-- 
1.7.7.1.msysgit.0

